@@ -49,27 +49,23 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def joined():
-            await self.sio.emit("watcher", {"target": self.target})
+            self.logger.info("joined")
+
 
         @self.sio.event
         async def broadcaster():
-            await self.sio.emit("watcher", {"target": self.target})
-
-        @self.sio.event
-        async def offer(id, description):
             if len(self.rtconfiList) > 0:
-                pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
+                self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
-                pc = RTCPeerConnection()
+                self.peerConnections = RTCPeerConnection()
 
-            @self.peerConnections.on("datachannel")
-            def on_datachannel(channel):
-                @channel.on("message")
-                def on_message(message):
-                    self.onmessage(self.gsdbs, self.target, message)
+            self.peerConnections.addTransceiver('video', direction='sendrecv')
 
             @self.peerConnections.on("iceconnectionstatechange")
             async def on_iceconnectionstatechange():
+                if self.peerConnections.iceConnectionState == "complete":
+                    pass
+
                 if self.peerConnections.iceConnectionState == "failed":
                     await self.peerConnections.close()
 
@@ -77,6 +73,7 @@ class GSPeerConnectionWatcher:
             async def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
+                        self.logger.info("on track received.Recording started")
                         await self.ontrack(self.gsdbs, track, self.target)
 
                 @track.on("ended")
@@ -84,16 +81,17 @@ class GSPeerConnectionWatcher:
                     pass
                     # await recorder.stop()
 
+            await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
+            await self.sio.emit("watcher",
+                                {"target": self.target,
+                                 "sdp": {"type": self.peerConnections.localDescription.type,
+                                         "sdp": self.peerConnections.localDescription.sdp}})
+
+        @self.sio.event
+        async def answer(id, description):
             desc = type('new_dict', (object,), ast.literal_eval(description))
             await self.peerConnections.setRemoteDescription(desc)
 
-            answer = await self.peerConnections.createAnswer()
-            await self.peerConnections.setLocalDescription(answer)
-            await self.sio.emit("answer", {"id": id,
-                                           "message": json.dumps(
-                                               {"type": self.peerConnections.localDescription.type,
-                                                "sdp": self.peerConnections.localDescription.sdp})})
-
         if "localhost" in self.gsdbs.credentials["signalserver"]:
             connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
         else:
